# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/tap/v3/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.tap.v3 import common_pb2 as envoy_dot_extensions_dot_common_dot_tap_dot_v3_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/extensions/filters/http/tap/v3/tap.proto\x12$envoy.extensions.filters.http.tap.v3\x1a+envoy/extensions/common/tap/v3/common.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xda\x01\n\x03Tap\x12V\n\rcommon_config\x18\x01 \x01(\x0b\x32\x35.envoy.extensions.common.tap.v3.CommonExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12$\n\x1crecord_headers_received_time\x18\x02 \x01(\x08\x12$\n\x1crecord_downstream_connection\x18\x03 \x01(\x08:/\x9a\xc5\x88\x1e*\n(envoy.config.filter.http.tap.v2alpha.TapB\x9b\x01\n2io.envoyproxy.envoy.extensions.filters.http.tap.v3B\x08TapProtoP\x01ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.tap.v3.tap_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2io.envoyproxy.envoy.extensions.filters.http.tap.v3B\010TapProtoP\001ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _TAP.fields_by_name['common_config']._options = None
  _TAP.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TAP._options = None
  _TAP._serialized_options = b'\232\305\210\036*\n(envoy.config.filter.http.tap.v2alpha.Tap'
  _globals['_TAP']._serialized_start=225
  _globals['_TAP']._serialized_end=443
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/grpc_credential/v2alpha/aws_iam.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/config/grpc_credential/v2alpha/aws_iam.proto\x12$envoy.config.grpc_credential.v2alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"=\n\x0c\x41wsIamConfig\x12\x1d\n\x0cservice_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x0e\n\x06region\x18\x02 \x01(\tB\x98\x01\n2io.envoyproxy.envoy.config.grpc_credential.v2alphaB\x0b\x41wsIamProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/config/grpc_credential/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.grpc_credential.v2alpha.aws_iam_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2io.envoyproxy.envoy.config.grpc_credential.v2alphaB\013AwsIamProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/config/grpc_credential/v2alpha\272\200\310\321\006\002\020\001'
  _AWSIAMCONFIG.fields_by_name['service_name']._options = None
  _AWSIAMCONFIG.fields_by_name['service_name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_AWSIAMCONFIG']._serialized_start=148
  _globals['_AWSIAMCONFIG']._serialized_end=209
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.aws.v3 import credential_provider_pb2 as envoy_dot_extensions_dot_common_dot_aws_dot_v3_dot_credential__provider__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto\x12\x34\x65nvoy.extensions.filters.http.aws_request_signing.v3\x1a\x38\x65nvoy/extensions/common/aws/v3/credential_provider.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc6\x05\n\x11\x41wsRequestSigning\x12\x1d\n\x0cservice_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x14\n\x0chost_rewrite\x18\x03 \x01(\t\x12\x1c\n\x14use_unsigned_payload\x18\x04 \x01(\x08\x12\x44\n\x16match_excluded_headers\x18\x05 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12s\n\x11signing_algorithm\x18\x06 \x01(\x0e\x32X.envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.SigningAlgorithm\x12i\n\x0cquery_string\x18\x07 \x01(\x0b\x32S.envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.QueryString\x12R\n\x13\x63redential_provider\x18\x08 \x01(\x0b\x32\x35.envoy.extensions.common.aws.v3.AwsCredentialProvider\x1aR\n\x0bQueryString\x12\x43\n\x0f\x65xpiration_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\xfa\x42\x0c\xaa\x01\t\"\x03\x08\x90\x1c\x32\x02\x08\x01\"1\n\x10SigningAlgorithm\x12\r\n\tAWS_SIGV4\x10\x00\x12\x0e\n\nAWS_SIGV4A\x10\x01:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigning\"\x9f\x01\n\x19\x41wsRequestSigningPerRoute\x12\x64\n\x13\x61ws_request_signing\x18\x01 \x01(\x0b\x32G.envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xd9\x01\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\x16\x41wsRequestSigningProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_request_signing/v3;aws_request_signingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.aws_request_signing.v3.aws_request_signing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\026AwsRequestSigningProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_request_signing/v3;aws_request_signingv3\272\200\310\321\006\002\020\002'
  _AWSREQUESTSIGNING_QUERYSTRING.fields_by_name['expiration_time']._options = None
  _AWSREQUESTSIGNING_QUERYSTRING.fields_by_name['expiration_time']._serialized_options = b'\372B\014\252\001\t\"\003\010\220\0342\002\010\001'
  _AWSREQUESTSIGNING.fields_by_name['service_name']._options = None
  _AWSREQUESTSIGNING.fields_by_name['service_name']._serialized_options = b'\372B\004r\002\020\001'
  _AWSREQUESTSIGNING._options = None
  _AWSREQUESTSIGNING._serialized_options = b'\232\305\210\036H\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigning'
  _AWSREQUESTSIGNINGPERROUTE.fields_by_name['stat_prefix']._options = None
  _AWSREQUESTSIGNINGPERROUTE.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_AWSREQUESTSIGNING']._serialized_start=354
  _globals['_AWSREQUESTSIGNING']._serialized_end=1064
  _globals['_AWSREQUESTSIGNING_QUERYSTRING']._serialized_start=852
  _globals['_AWSREQUESTSIGNING_QUERYSTRING']._serialized_end=934
  _globals['_AWSREQUESTSIGNING_SIGNINGALGORITHM']._serialized_start=936
  _globals['_AWSREQUESTSIGNING_SIGNINGALGORITHM']._serialized_end=985
  _globals['_AWSREQUESTSIGNINGPERROUTE']._serialized_start=1067
  _globals['_AWSREQUESTSIGNINGPERROUTE']._serialized_end=1226
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/serviceusage/v1/serviceusage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api.serviceusage.v1 import resources_pb2 as google_dot_api_dot_serviceusage_dot_v1_dot_resources__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-google/api/serviceusage/v1/serviceusage.proto\x12\x1agoogle.api.serviceusage.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a*google/api/serviceusage/v1/resources.proto\x1a#google/longrunning/operations.proto\"$\n\x14\x45nableServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"M\n\x15\x45nableServiceResponse\x12\x34\n\x07service\x18\x01 \x01(\x0b\x32#.google.api.serviceusage.v1.Service\"\x92\x02\n\x15\x44isableServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x1a\x64isable_dependent_services\x18\x02 \x01(\x08\x12l\n\x1a\x63heck_if_service_has_usage\x18\x03 \x01(\x0e\x32H.google.api.serviceusage.v1.DisableServiceRequest.CheckIfServiceHasUsage\"Y\n\x16\x43heckIfServiceHasUsage\x12*\n&CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED\x10\x00\x12\x08\n\x04SKIP\x10\x01\x12\t\n\x05\x43HECK\x10\x02\"N\n\x16\x44isableServiceResponse\x12\x34\n\x07service\x18\x01 \x01(\x0b\x32#.google.api.serviceusage.v1.Service\"!\n\x11GetServiceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\\\n\x13ListServicesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"f\n\x14ListServicesResponse\x12\x35\n\x08services\x18\x01 \x03(\x0b\x32#.google.api.serviceusage.v1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"A\n\x1a\x42\x61tchEnableServicesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x13\n\x0bservice_ids\x18\x02 \x03(\t\"\xe9\x01\n\x1b\x42\x61tchEnableServicesResponse\x12\x35\n\x08services\x18\x01 \x03(\x0b\x32#.google.api.serviceusage.v1.Service\x12W\n\x08\x66\x61ilures\x18\x02 \x03(\x0b\x32\x45.google.api.serviceusage.v1.BatchEnableServicesResponse.EnableFailure\x1a:\n\rEnableFailure\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\"8\n\x17\x42\x61tchGetServicesRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"Q\n\x18\x42\x61tchGetServicesResponse\x12\x35\n\x08services\x18\x01 \x03(\x0b\x32#.google.api.serviceusage.v1.Service2\xe8\t\n\x0cServiceUsage\x12\xba\x01\n\rEnableService\x12\x30.google.api.serviceusage.v1.EnableServiceRequest\x1a\x1d.google.longrunning.Operation\"X\xca\x41*\n\x15\x45nableServiceResponse\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02%\" /v1/{name=*/*/services/*}:enable:\x01*\x12\xbe\x01\n\x0e\x44isableService\x12\x31.google.api.serviceusage.v1.DisableServiceRequest\x1a\x1d.google.longrunning.Operation\"Z\xca\x41+\n\x16\x44isableServiceResponse\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02&\"!/v1/{name=*/*/services/*}:disable:\x01*\x12\x83\x01\n\nGetService\x12-.google.api.serviceusage.v1.GetServiceRequest\x1a#.google.api.serviceusage.v1.Service\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/{name=*/*/services/*}\x12\x94\x01\n\x0cListServices\x12/.google.api.serviceusage.v1.ListServicesRequest\x1a\x30.google.api.serviceusage.v1.ListServicesResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/{parent=*/*}/services\x12\xd1\x01\n\x13\x42\x61tchEnableServices\x12\x36.google.api.serviceusage.v1.BatchEnableServicesRequest\x1a\x1d.google.longrunning.Operation\"c\xca\x41\x30\n\x1b\x42\x61tchEnableServicesResponse\x12\x11OperationMetadata\x82\xd3\xe4\x93\x02*\"%/v1/{parent=*/*}/services:batchEnable:\x01*\x12\xa9\x01\n\x10\x42\x61tchGetServices\x12\x33.google.api.serviceusage.v1.BatchGetServicesRequest\x1a\x34.google.api.serviceusage.v1.BatchGetServicesResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/{parent=*/*}/services:batchGet\x1a\xbc\x01\xca\x41\x1bserviceusage.googleapis.com\xd2\x41\x9a\x01https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/service.managementB\xdb\x01\n\x1e\x63om.google.api.serviceusage.v1B\x11ServiceUsageProtoP\x01ZDcloud.google.com/go/serviceusage/apiv1/serviceusagepb;serviceusagepb\xaa\x02\x1cGoogle.Cloud.ServiceUsage.V1\xca\x02\x1cGoogle\\Cloud\\ServiceUsage\\V1\xea\x02\x1fGoogle::Cloud::ServiceUsage::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.serviceusage.v1.serviceusage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.google.api.serviceusage.v1B\021ServiceUsageProtoP\001ZDcloud.google.com/go/serviceusage/apiv1/serviceusagepb;serviceusagepb\252\002\034Google.Cloud.ServiceUsage.V1\312\002\034Google\\Cloud\\ServiceUsage\\V1\352\002\037Google::Cloud::ServiceUsage::V1'
  _SERVICEUSAGE._options = None
  _SERVICEUSAGE._serialized_options = b'\312A\033serviceusage.googleapis.com\322A\232\001https://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/cloud-platform.read-only,https://www.googleapis.com/auth/service.management'
  _SERVICEUSAGE.methods_by_name['EnableService']._options = None
  _SERVICEUSAGE.methods_by_name['EnableService']._serialized_options = b'\312A*\n\025EnableServiceResponse\022\021OperationMetadata\202\323\344\223\002%\" /v1/{name=*/*/services/*}:enable:\001*'
  _SERVICEUSAGE.methods_by_name['DisableService']._options = None
  _SERVICEUSAGE.methods_by_name['DisableService']._serialized_options = b'\312A+\n\026DisableServiceResponse\022\021OperationMetadata\202\323\344\223\002&\"!/v1/{name=*/*/services/*}:disable:\001*'
  _SERVICEUSAGE.methods_by_name['GetService']._options = None
  _SERVICEUSAGE.methods_by_name['GetService']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/{name=*/*/services/*}'
  _SERVICEUSAGE.methods_by_name['ListServices']._options = None
  _SERVICEUSAGE.methods_by_name['ListServices']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/{parent=*/*}/services'
  _SERVICEUSAGE.methods_by_name['BatchEnableServices']._options = None
  _SERVICEUSAGE.methods_by_name['BatchEnableServices']._serialized_options = b'\312A0\n\033BatchEnableServicesResponse\022\021OperationMetadata\202\323\344\223\002*\"%/v1/{parent=*/*}/services:batchEnable:\001*'
  _SERVICEUSAGE.methods_by_name['BatchGetServices']._options = None
  _SERVICEUSAGE.methods_by_name['BatchGetServices']._serialized_options = b'\202\323\344\223\002$\022\"/v1/{parent=*/*}/services:batchGet'
  _globals['_ENABLESERVICEREQUEST']._serialized_start=213
  _globals['_ENABLESERVICEREQUEST']._serialized_end=249
  _globals['_ENABLESERVICERESPONSE']._serialized_start=251
  _globals['_ENABLESERVICERESPONSE']._serialized_end=328
  _globals['_DISABLESERVICEREQUEST']._serialized_start=331
  _globals['_DISABLESERVICEREQUEST']._serialized_end=605
  _globals['_DISABLESERVICEREQUEST_CHECKIFSERVICEHASUSAGE']._serialized_start=516
  _globals['_DISABLESERVICEREQUEST_CHECKIFSERVICEHASUSAGE']._serialized_end=605
  _globals['_DISABLESERVICERESPONSE']._serialized_start=607
  _globals['_DISABLESERVICERESPONSE']._serialized_end=685
  _globals['_GETSERVICEREQUEST']._serialized_start=687
  _globals['_GETSERVICEREQUEST']._serialized_end=720
  _globals['_LISTSERVICESREQUEST']._serialized_start=722
  _globals['_LISTSERVICESREQUEST']._serialized_end=814
  _globals['_LISTSERVICESRESPONSE']._serialized_start=816
  _globals['_LISTSERVICESRESPONSE']._serialized_end=918
  _globals['_BATCHENABLESERVICESREQUEST']._serialized_start=920
  _globals['_BATCHENABLESERVICESREQUEST']._serialized_end=985
  _globals['_BATCHENABLESERVICESRESPONSE']._serialized_start=988
  _globals['_BATCHENABLESERVICESRESPONSE']._serialized_end=1221
  _globals['_BATCHENABLESERVICESRESPONSE_ENABLEFAILURE']._serialized_start=1163
  _globals['_BATCHENABLESERVICESRESPONSE_ENABLEFAILURE']._serialized_end=1221
  _globals['_BATCHGETSERVICESREQUEST']._serialized_start=1223
  _globals['_BATCHGETSERVICESREQUEST']._serialized_end=1279
  _globals['_BATCHGETSERVICESRESPONSE']._serialized_start=1281
  _globals['_BATCHGETSERVICESRESPONSE']._serialized_end=1362
  _globals['_SERVICEUSAGE']._serialized_start=1365
  _globals['_SERVICEUSAGE']._serialized_end=2621
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/geoip_providers/maxmind/v3/maxmind.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.geoip_providers.common.v3 import common_pb2 as envoy_dot_extensions_dot_geoip__providers_dot_common_dot_v3_dot_common__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9envoy/extensions/geoip_providers/maxmind/v3/maxmind.proto\x12+envoy.extensions.geoip_providers.maxmind.v3\x1a\x37\x65nvoy/extensions/geoip_providers/common/v3/common.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x83\x02\n\rMaxMindConfig\x12*\n\x0c\x63ity_db_path\x18\x01 \x01(\tB\x14\xfa\x42\x11r\x0f\x32\r^$|^.*\\.mmdb$\x12)\n\x0bisp_db_path\x18\x02 \x01(\tB\x14\xfa\x42\x11r\x0f\x32\r^$|^.*\\.mmdb$\x12*\n\x0c\x61non_db_path\x18\x03 \x01(\tB\x14\xfa\x42\x11r\x0f\x32\r^$|^.*\\.mmdb$\x12o\n\x16\x63ommon_provider_config\x18\x04 \x01(\x0b\x32\x45.envoy.extensions.geoip_providers.common.v3.CommonGeoipProviderConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xb9\x01\n9io.envoyproxy.envoy.extensions.geoip_providers.maxmind.v3B\x0cMaxmindProtoP\x01Z\\github.com/envoyproxy/go-control-plane/envoy/extensions/geoip_providers/maxmind/v3;maxmindv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.geoip_providers.maxmind.v3.maxmind_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n9io.envoyproxy.envoy.extensions.geoip_providers.maxmind.v3B\014MaxmindProtoP\001Z\\github.com/envoyproxy/go-control-plane/envoy/extensions/geoip_providers/maxmind/v3;maxmindv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _MAXMINDCONFIG.fields_by_name['city_db_path']._options = None
  _MAXMINDCONFIG.fields_by_name['city_db_path']._serialized_options = b'\372B\021r\0172\r^$|^.*\\.mmdb$'
  _MAXMINDCONFIG.fields_by_name['isp_db_path']._options = None
  _MAXMINDCONFIG.fields_by_name['isp_db_path']._serialized_options = b'\372B\021r\0172\r^$|^.*\\.mmdb$'
  _MAXMINDCONFIG.fields_by_name['anon_db_path']._options = None
  _MAXMINDCONFIG.fields_by_name['anon_db_path']._serialized_options = b'\372B\021r\0172\r^$|^.*\\.mmdb$'
  _MAXMINDCONFIG.fields_by_name['common_provider_config']._options = None
  _MAXMINDCONFIG.fields_by_name['common_provider_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_MAXMINDCONFIG']._serialized_start=253
  _globals['_MAXMINDCONFIG']._serialized_end=512
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/annotations/v3/security.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!xds/annotations/v3/security.proto\x12\x12xds.annotations.v3\x1a\x1fxds/annotations/v3/status.proto\x1a google/protobuf/descriptor.proto\"o\n\x17\x46ieldSecurityAnnotation\x12*\n\"configure_for_untrusted_downstream\x18\x01 \x01(\x08\x12(\n configure_for_untrusted_upstream\x18\x02 \x01(\x08:_\n\x08security\x12\x1d.google.protobuf.FieldOptions\x18\xa7\x96\x9d/ \x01(\x0b\x32+.xds.annotations.v3.FieldSecurityAnnotationB3Z)github.com/cncf/xds/go/xds/annotations/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.annotations.v3.security_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cncf/xds/go/xds/annotations/v3\322\306\244\341\006\002\010\001'
  _globals['_FIELDSECURITYANNOTATION']._serialized_start=124
  _globals['_FIELDSECURITYANNOTATION']._serialized_end=235
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/resource_monitors/cpu_utilization/v3/cpu_utilization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKenvoy/extensions/resource_monitors/cpu_utilization/v3/cpu_utilization.proto\x12\x35\x65nvoy.extensions.resource_monitors.cpu_utilization.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcd\x01\n\x14\x43puUtilizationConfig\x12~\n\x04mode\x18\x01 \x01(\x0e\x32\x66.envoy.extensions.resource_monitors.cpu_utilization.v3.CpuUtilizationConfig.UtilizationComputeStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"5\n\x1aUtilizationComputeStrategy\x12\x08\n\x04HOST\x10\x00\x12\r\n\tCONTAINER\x10\x01\x42\xd4\x01\nCio.envoyproxy.envoy.extensions.resource_monitors.cpu_utilization.v3B\x13\x43puUtilizationProtoP\x01Zngithub.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/cpu_utilization/v3;cpu_utilizationv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.resource_monitors.cpu_utilization.v3.cpu_utilization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.extensions.resource_monitors.cpu_utilization.v3B\023CpuUtilizationProtoP\001Zngithub.com/envoyproxy/go-control-plane/envoy/extensions/resource_monitors/cpu_utilization/v3;cpu_utilizationv3\272\200\310\321\006\002\020\002'
  _CPUUTILIZATIONCONFIG.fields_by_name['mode']._options = None
  _CPUUTILIZATIONCONFIG.fields_by_name['mode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CPUUTILIZATIONCONFIG']._serialized_start=191
  _globals['_CPUUTILIZATIONCONFIG']._serialized_end=396
  _globals['_CPUUTILIZATIONCONFIG_UTILIZATIONCOMPUTESTRATEGY']._serialized_start=343
  _globals['_CPUUTILIZATIONCONFIG_UTILIZATIONCOMPUTESTRATEGY']._serialized_end=396
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/core/v3/health_check_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+envoy/data/core/v3/health_check_event.proto\x12\x12\x65nvoy.data.core.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcf\x06\n\x10HealthCheckEvent\x12L\n\x13health_checker_type\x18\x01 \x01(\x0e\x32%.envoy.data.core.v3.HealthCheckerTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12+\n\x04host\x18\x02 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12\x1d\n\x0c\x63luster_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12N\n\x15\x65ject_unhealthy_event\x18\x04 \x01(\x0b\x32-.envoy.data.core.v3.HealthCheckEjectUnhealthyH\x00\x12\x46\n\x11\x61\x64\x64_healthy_event\x18\x05 \x01(\x0b\x32).envoy.data.core.v3.HealthCheckAddHealthyH\x00\x12R\n\x1dsuccessful_health_check_event\x18\x0c \x01(\x0b\x32).envoy.data.core.v3.HealthCheckSuccessfulH\x00\x12L\n\x1ahealth_check_failure_event\x18\x07 \x01(\x0b\x32&.envoy.data.core.v3.HealthCheckFailureH\x00\x12H\n\x15\x64\x65graded_healthy_host\x18\x08 \x01(\x0b\x32\'.envoy.data.core.v3.DegradedHealthyHostH\x00\x12K\n\x17no_longer_degraded_host\x18\t \x01(\x0b\x32(.envoy.data.core.v3.NoLongerDegradedHostH\x00\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x08metadata\x18\n \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12\x30\n\x08locality\x18\x0b \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality:/\x9a\xc5\x88\x1e*\n(envoy.data.core.v2alpha.HealthCheckEventB\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xa1\x01\n\x19HealthCheckEjectUnhealthy\x12J\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32*.envoy.data.core.v3.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:8\x9a\xc5\x88\x1e\x33\n1envoy.data.core.v2alpha.HealthCheckEjectUnhealthy\"b\n\x15HealthCheckAddHealthy\x12\x13\n\x0b\x66irst_check\x18\x01 \x01(\x08:4\x9a\xc5\x88\x1e/\n-envoy.data.core.v2alpha.HealthCheckAddHealthy\"\x17\n\x15HealthCheckSuccessful\"\xa8\x01\n\x12HealthCheckFailure\x12J\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32*.envoy.data.core.v3.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x13\n\x0b\x66irst_check\x18\x02 \x01(\x08:1\x9a\xc5\x88\x1e,\n*envoy.data.core.v2alpha.HealthCheckFailure\"I\n\x13\x44\x65gradedHealthyHost:2\x9a\xc5\x88\x1e-\n+envoy.data.core.v2alpha.DegradedHealthyHost\"K\n\x14NoLongerDegradedHost:3\x9a\xc5\x88\x1e.\n,envoy.data.core.v2alpha.NoLongerDegradedHost*S\n\x16HealthCheckFailureType\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0b\n\x07PASSIVE\x10\x01\x12\x0b\n\x07NETWORK\x10\x02\x12\x13\n\x0fNETWORK_TIMEOUT\x10\x03*G\n\x11HealthCheckerType\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\t\n\x05REDIS\x10\x03\x12\n\n\x06THRIFT\x10\x04\x42\x85\x01\n io.envoyproxy.envoy.data.core.v3B\x15HealthCheckEventProtoP\x01Z@github.com/envoyproxy/go-control-plane/envoy/data/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.core.v3.health_check_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.data.core.v3B\025HealthCheckEventProtoP\001Z@github.com/envoyproxy/go-control-plane/envoy/data/core/v3;corev3\272\200\310\321\006\002\020\002'
  _HEALTHCHECKEVENT.oneofs_by_name['event']._options = None
  _HEALTHCHECKEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _HEALTHCHECKEVENT.fields_by_name['health_checker_type']._options = None
  _HEALTHCHECKEVENT.fields_by_name['health_checker_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKEVENT.fields_by_name['cluster_name']._options = None
  _HEALTHCHECKEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _HEALTHCHECKEVENT._options = None
  _HEALTHCHECKEVENT._serialized_options = b'\232\305\210\036*\n(envoy.data.core.v2alpha.HealthCheckEvent'
  _HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._options = None
  _HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKEJECTUNHEALTHY._options = None
  _HEALTHCHECKEJECTUNHEALTHY._serialized_options = b'\232\305\210\0363\n1envoy.data.core.v2alpha.HealthCheckEjectUnhealthy'
  _HEALTHCHECKADDHEALTHY._options = None
  _HEALTHCHECKADDHEALTHY._serialized_options = b'\232\305\210\036/\n-envoy.data.core.v2alpha.HealthCheckAddHealthy'
  _HEALTHCHECKFAILURE.fields_by_name['failure_type']._options = None
  _HEALTHCHECKFAILURE.fields_by_name['failure_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKFAILURE._options = None
  _HEALTHCHECKFAILURE._serialized_options = b'\232\305\210\036,\n*envoy.data.core.v2alpha.HealthCheckFailure'
  _DEGRADEDHEALTHYHOST._options = None
  _DEGRADEDHEALTHYHOST._serialized_options = b'\232\305\210\036-\n+envoy.data.core.v2alpha.DegradedHealthyHost'
  _NOLONGERDEGRADEDHOST._options = None
  _NOLONGERDEGRADEDHOST._serialized_options = b'\232\305\210\036.\n,envoy.data.core.v2alpha.NoLongerDegradedHost'
  _globals['_HEALTHCHECKFAILURETYPE']._serialized_start=1722
  _globals['_HEALTHCHECKFAILURETYPE']._serialized_end=1805
  _globals['_HEALTHCHECKERTYPE']._serialized_start=1807
  _globals['_HEALTHCHECKERTYPE']._serialized_end=1878
  _globals['_HEALTHCHECKEVENT']._serialized_start=261
  _globals['_HEALTHCHECKEVENT']._serialized_end=1108
  _globals['_HEALTHCHECKEJECTUNHEALTHY']._serialized_start=1111
  _globals['_HEALTHCHECKEJECTUNHEALTHY']._serialized_end=1272
  _globals['_HEALTHCHECKADDHEALTHY']._serialized_start=1274
  _globals['_HEALTHCHECKADDHEALTHY']._serialized_end=1372
  _globals['_HEALTHCHECKSUCCESSFUL']._serialized_start=1374
  _globals['_HEALTHCHECKSUCCESSFUL']._serialized_end=1397
  _globals['_HEALTHCHECKFAILURE']._serialized_start=1400
  _globals['_HEALTHCHECKFAILURE']._serialized_end=1568
  _globals['_DEGRADEDHEALTHYHOST']._serialized_start=1570
  _globals['_DEGRADEDHEALTHYHOST']._serialized_end=1643
  _globals['_NOLONGERDEGRADEDHOST']._serialized_start=1645
  _globals['_NOLONGERDEGRADEDHOST']._serialized_end=1720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/ext_authz/v2/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.type import http_status_pb2 as envoy_dot_type_dot_http__status__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5envoy/config/filter/http/ext_authz/v2/ext_authz.proto\x12%envoy.config.filter.http.ext_authz.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/grpc_service.proto\x1a envoy/api/v2/core/http_uri.proto\x1a\x1c\x65nvoy/type/http_status.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x04\n\x08\x45xtAuthz\x12\x36\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceH\x00\x12J\n\x0chttp_service\x18\x03 \x01(\x0b\x32\x32.envoy.config.filter.http.ext_authz.v2.HttpServiceH\x00\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12\x1b\n\tuse_alpha\x18\x04 \x01(\x08\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12P\n\x11with_request_body\x18\x05 \x01(\x0b\x32\x35.envoy.config.filter.http.ext_authz.v2.BufferSettings\x12\x19\n\x11\x63lear_route_cache\x18\x06 \x01(\x08\x12/\n\x0fstatus_on_error\x18\x07 \x01(\x0b\x32\x16.envoy.type.HttpStatus\x12#\n\x1bmetadata_context_namespaces\x18\x08 \x03(\t\x12\x43\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12>\n\x0f\x64\x65ny_at_disable\x18\x0b \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlag\x12 \n\x18include_peer_certificate\x18\n \x01(\x08\x42\n\n\x08services\"S\n\x0e\x42ufferSettings\x12\"\n\x11max_request_bytes\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x1d\n\x15\x61llow_partial_message\x18\x02 \x01(\x08\"\xa4\x02\n\x0bHttpService\x12.\n\nserver_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUri\x12\x13\n\x0bpath_prefix\x18\x02 \x01(\t\x12Z\n\x15\x61uthorization_request\x18\x07 \x01(\x0b\x32;.envoy.config.filter.http.ext_authz.v2.AuthorizationRequest\x12\\\n\x16\x61uthorization_response\x18\x08 \x01(\x0b\x32<.envoy.config.filter.http.ext_authz.v2.AuthorizationResponseJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x8e\x01\n\x14\x41uthorizationRequest\x12>\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\x12\x36\n\x0eheaders_to_add\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"\xa7\x01\n\x15\x41uthorizationResponse\x12G\n\x18\x61llowed_upstream_headers\x18\x01 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\x12\x45\n\x16\x61llowed_client_headers\x18\x02 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\"\x9a\x01\n\x10\x45xtAuthzPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12X\n\x0e\x63heck_settings\x18\x02 \x01(\x0b\x32\x34.envoy.config.filter.http.ext_authz.v2.CheckSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xb2\x01\n\rCheckSettings\x12g\n\x12\x63ontext_extensions\x18\x01 \x03(\x0b\x32K.envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\xda\x01\n3io.envoyproxy.envoy.config.filter.http.ext_authz.v2B\rExtAuthzProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/ext_authz/v2;ext_authzv2\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.ext_authz.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n3io.envoyproxy.envoy.config.filter.http.ext_authz.v2B\rExtAuthzProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/ext_authz/v2;ext_authzv2\362\230\376\217\005,\022*envoy.extensions.filters.http.ext_authz.v3\272\200\310\321\006\002\020\001'
  _EXTAUTHZ.fields_by_name['use_alpha']._options = None
  _EXTAUTHZ.fields_by_name['use_alpha']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _BUFFERSETTINGS.fields_by_name['max_request_bytes']._options = None
  _BUFFERSETTINGS.fields_by_name['max_request_bytes']._serialized_options = b'\372B\004*\002 \000'
  _EXTAUTHZPERROUTE.oneofs_by_name['override']._options = None
  _EXTAUTHZPERROUTE.oneofs_by_name['override']._serialized_options = b'\370B\001'
  _EXTAUTHZPERROUTE.fields_by_name['disabled']._options = None
  _EXTAUTHZPERROUTE.fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _EXTAUTHZPERROUTE.fields_by_name['check_settings']._options = None
  _EXTAUTHZPERROUTE.fields_by_name['check_settings']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._options = None
  _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._serialized_options = b'8\001'
  _globals['_EXTAUTHZ']._serialized_start=387
  _globals['_EXTAUTHZ']._serialized_end=960
  _globals['_BUFFERSETTINGS']._serialized_start=962
  _globals['_BUFFERSETTINGS']._serialized_end=1045
  _globals['_HTTPSERVICE']._serialized_start=1048
  _globals['_HTTPSERVICE']._serialized_end=1340
  _globals['_AUTHORIZATIONREQUEST']._serialized_start=1343
  _globals['_AUTHORIZATIONREQUEST']._serialized_end=1485
  _globals['_AUTHORIZATIONRESPONSE']._serialized_start=1488
  _globals['_AUTHORIZATIONRESPONSE']._serialized_end=1655
  _globals['_EXTAUTHZPERROUTE']._serialized_start=1658
  _globals['_EXTAUTHZPERROUTE']._serialized_end=1812
  _globals['_CHECKSETTINGS']._serialized_start=1815
  _globals['_CHECKSETTINGS']._serialized_end=1993
  _globals['_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY']._serialized_start=1937
  _globals['_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY']._serialized_end=1993
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/outlier_detection_monitors/common/v3/error_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/outlier_detection_monitors/common/v3/error_types.proto\x12\x35\x65nvoy.extensions.outlier_detection_monitors.common.v3\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1dudpa/annotations/status.proto\"6\n\nHttpErrors\x12(\n\x05range\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.Int32Range\"\x13\n\x11LocalOriginErrors\"\x10\n\x0e\x44\x61tabaseErrors\"\xad\x02\n\x0c\x45rrorBuckets\x12V\n\x0bhttp_errors\x18\x01 \x03(\x0b\x32\x41.envoy.extensions.outlier_detection_monitors.common.v3.HttpErrors\x12\x65\n\x13local_origin_errors\x18\x02 \x03(\x0b\x32H.envoy.extensions.outlier_detection_monitors.common.v3.LocalOriginErrors\x12^\n\x0f\x64\x61tabase_errors\x18\x03 \x03(\x0b\x32\x45.envoy.extensions.outlier_detection_monitors.common.v3.DatabaseErrorsB\xc7\x01\nCio.envoyproxy.envoy.extensions.outlier_detection_monitors.common.v3B\x0f\x45rrorTypesProtoP\x01Zegithub.com/envoyproxy/go-control-plane/envoy/extensions/outlier_detection_monitors/common/v3;commonv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.outlier_detection_monitors.common.v3.error_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.extensions.outlier_detection_monitors.common.v3B\017ErrorTypesProtoP\001Zegithub.com/envoyproxy/go-control-plane/envoy/extensions/outlier_detection_monitors/common/v3;commonv3\272\200\310\321\006\002\020\002'
  _globals['_HTTPERRORS']._serialized_start=188
  _globals['_HTTPERRORS']._serialized_end=242
  _globals['_LOCALORIGINERRORS']._serialized_start=244
  _globals['_LOCALORIGINERRORS']._serialized_end=263
  _globals['_DATABASEERRORS']._serialized_start=265
  _globals['_DATABASEERRORS']._serialized_end=281
  _globals['_ERRORBUCKETS']._serialized_start=284
  _globals['_ERRORBUCKETS']._serialized_end=585
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/scoped_route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/api/v2/scoped_route.proto\x12\x0c\x65nvoy.api.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa8\x02\n\x18ScopedRouteConfiguration\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12)\n\x18route_configuration_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x41\n\x03key\x18\x03 \x01(\x0b\x32*.envoy.api.v2.ScopedRouteConfiguration.KeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\x86\x01\n\x03Key\x12P\n\tfragments\x18\x01 \x03(\x0b\x32\x33.envoy.api.v2.ScopedRouteConfiguration.Key.FragmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a-\n\x08\x46ragment\x12\x14\n\nstring_key\x18\x01 \x01(\tH\x00\x42\x0b\n\x04type\x12\x03\xf8\x42\x01\x42\x90\x01\n\x1aio.envoyproxy.envoy.api.v2B\x10ScopedRouteProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x17\x12\x15\x65nvoy.config.route.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.scoped_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\020ScopedRouteProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\027\022\025envoy.config.route.v3\272\200\310\321\006\002\020\001'
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type']._options = None
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type']._serialized_options = b'\370B\001'
  _SCOPEDROUTECONFIGURATION_KEY.fields_by_name['fragments']._options = None
  _SCOPEDROUTECONFIGURATION_KEY.fields_by_name['fragments']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SCOPEDROUTECONFIGURATION.fields_by_name['name']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration_name']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration_name']._serialized_options = b'\372B\004r\002 \001'
  _SCOPEDROUTECONFIGURATION.fields_by_name['key']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_SCOPEDROUTECONFIGURATION']._serialized_start=138
  _globals['_SCOPEDROUTECONFIGURATION']._serialized_end=434
  _globals['_SCOPEDROUTECONFIGURATION_KEY']._serialized_start=300
  _globals['_SCOPEDROUTECONFIGURATION_KEY']._serialized_end=434
  _globals['_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT']._serialized_start=389
  _globals['_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT']._serialized_end=434
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.load_stats.v3 import lrs_pb2 as envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2


class LoadReportingServiceStub(object):
    """[#protodoc-title: Load reporting service (LRS)]

    Load Reporting Service is an Envoy API to emit load reports. Envoy will initiate a bi-directional
    stream with a management server. Upon connecting, the management server can send a
    :ref:`LoadStatsResponse <envoy_v3_api_msg_service.load_stats.v3.LoadStatsResponse>` to a node it is
    interested in getting the load reports for. Envoy in this node will start sending
    :ref:`LoadStatsRequest <envoy_v3_api_msg_service.load_stats.v3.LoadStatsRequest>`. This is done periodically
    based on the :ref:`load reporting interval <envoy_v3_api_field_service.load_stats.v3.LoadStatsResponse.load_reporting_interval>`
    For details, take a look at the :ref:`Load Reporting Service sandbox example <install_sandboxes_load_reporting_service>`.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamLoadStats = channel.stream_stream(
                '/envoy.service.load_stats.v3.LoadReportingService/StreamLoadStats',
                request_serializer=envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2.LoadStatsRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2.LoadStatsResponse.FromString,
                )


class LoadReportingServiceServicer(object):
    """[#protodoc-title: Load reporting service (LRS)]

    Load Reporting Service is an Envoy API to emit load reports. Envoy will initiate a bi-directional
    stream with a management server. Upon connecting, the management server can send a
    :ref:`LoadStatsResponse <envoy_v3_api_msg_service.load_stats.v3.LoadStatsResponse>` to a node it is
    interested in getting the load reports for. Envoy in this node will start sending
    :ref:`LoadStatsRequest <envoy_v3_api_msg_service.load_stats.v3.LoadStatsRequest>`. This is done periodically
    based on the :ref:`load reporting interval <envoy_v3_api_field_service.load_stats.v3.LoadStatsResponse.load_reporting_interval>`
    For details, take a look at the :ref:`Load Reporting Service sandbox example <install_sandboxes_load_reporting_service>`.

    """

    def StreamLoadStats(self, request_iterator, context):
        """Advanced API to allow for multi-dimensional load balancing by remote
        server. For receiving LB assignments, the steps are:
        1, The management server is configured with per cluster/zone/load metric
        capacity configuration. The capacity configuration definition is
        outside of the scope of this document.
        2. Envoy issues a standard {Stream,Fetch}Endpoints request for the clusters
        to balance.

        Independently, Envoy will initiate a StreamLoadStats bidi stream with a
        management server:
        1. Once a connection establishes, the management server publishes a
        LoadStatsResponse for all clusters it is interested in learning load
        stats about.
        2. For each cluster, Envoy load balances incoming traffic to upstream hosts
        based on per-zone weights and/or per-instance weights (if specified)
        based on intra-zone LbPolicy. This information comes from the above
        {Stream,Fetch}Endpoints.
        3. When upstream hosts reply, they optionally add header <define header
        name> with ASCII representation of EndpointLoadMetricStats.
        4. Envoy aggregates load reports over the period of time given to it in
        LoadStatsResponse.load_reporting_interval. This includes aggregation
        stats Envoy maintains by itself (total_requests, rpc_errors etc.) as
        well as load metrics from upstream hosts.
        5. When the timer of load_reporting_interval expires, Envoy sends new
        LoadStatsRequest filled with load reports for each cluster.
        6. The management server uses the load reports from all reported Envoys
        from around the world, computes global assignment and prepares traffic
        assignment destined for each zone Envoys are located in. Goto 2.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LoadReportingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamLoadStats': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamLoadStats,
                    request_deserializer=envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2.LoadStatsRequest.FromString,
                    response_serializer=envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2.LoadStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.load_stats.v3.LoadReportingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LoadReportingService(object):
    """[#protodoc-title: Load reporting service (LRS)]

    Load Reporting Service is an Envoy API to emit load reports. Envoy will initiate a bi-directional
    stream with a management server. Upon connecting, the management server can send a
    :ref:`LoadStatsResponse <envoy_v3_api_msg_service.load_stats.v3.LoadStatsResponse>` to a node it is
    interested in getting the load reports for. Envoy in this node will start sending
    :ref:`LoadStatsRequest <envoy_v3_api_msg_service.load_stats.v3.LoadStatsRequest>`. This is done periodically
    based on the :ref:`load reporting interval <envoy_v3_api_field_service.load_stats.v3.LoadStatsResponse.load_reporting_interval>`
    For details, take a look at the :ref:`Load Reporting Service sandbox example <install_sandboxes_load_reporting_service>`.

    """

    @staticmethod
    def StreamLoadStats(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/envoy.service.load_stats.v3.LoadReportingService/StreamLoadStats',
            envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2.LoadStatsRequest.SerializeToString,
            envoy_dot_service_dot_load__stats_dot_v3_dot_lrs__pb2.LoadStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/previous_priorities/previous_priorities_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/config/retry/previous_priorities/previous_priorities_config.proto\x12&envoy.config.retry.previous_priorities\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"=\n\x18PreviousPrioritiesConfig\x12!\n\x10update_frequency\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02 \x00\x42\xec\x01\n4io.envoyproxy.envoy.config.retry.previous_prioritiesB\x1dPreviousPrioritiesConfigProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/config/retry/previous_priorities\xf2\x98\xfe\x8f\x05\x38\x12\x36\x65nvoy.extensions.retry.priority.previous_priorities.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.retry.previous_priorities.previous_priorities_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.config.retry.previous_prioritiesB\035PreviousPrioritiesConfigProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/config/retry/previous_priorities\362\230\376\217\0058\0226envoy.extensions.retry.priority.previous_priorities.v3\272\200\310\321\006\002\020\001'
  _PREVIOUSPRIORITIESCONFIG.fields_by_name['update_frequency']._options = None
  _PREVIOUSPRIORITIESCONFIG.fields_by_name['update_frequency']._serialized_options = b'\372B\004\032\002 \000'
  _globals['_PREVIOUSPRIORITIESCONFIG']._serialized_start=203
  _globals['_PREVIOUSPRIORITIESCONFIG']._serialized_end=264
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/socket_option.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/api/v2/core/socket_option.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x86\x02\n\x0cSocketOption\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\x03\x12\x13\n\tint_value\x18\x04 \x01(\x03H\x00\x12\x13\n\tbuf_value\x18\x05 \x01(\x0cH\x00\x12\x44\n\x05state\x18\x06 \x01(\x0e\x32+.envoy.api.v2.core.SocketOption.SocketStateB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x0bSocketState\x12\x11\n\rSTATE_PREBIND\x10\x00\x12\x0f\n\x0bSTATE_BOUND\x10\x01\x12\x13\n\x0fSTATE_LISTENING\x10\x02\x42\x0c\n\x05value\x12\x03\xf8\x42\x01\x42\x94\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x11SocketOptionProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.socket_option_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\021SocketOptionProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _SOCKETOPTION.oneofs_by_name['value']._options = None
  _SOCKETOPTION.oneofs_by_name['value']._serialized_options = b'\370B\001'
  _SOCKETOPTION.fields_by_name['state']._options = None
  _SOCKETOPTION.fields_by_name['state']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_SOCKETOPTION']._serialized_start=149
  _globals['_SOCKETOPTION']._serialized_end=411
  _globals['_SOCKETOPTION_SOCKETSTATE']._serialized_start=327
  _globals['_SOCKETOPTION_SOCKETSTATE']._serialized_end=397
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/sni_cluster/v2/sni_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/config/filter/network/sni_cluster/v2/sni_cluster.proto\x12*envoy.config.filter.network.sni_cluster.v2\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x0c\n\nSniClusterB\xed\x01\n8io.envoyproxy.envoy.config.filter.network.sni_cluster.v2B\x0fSniClusterProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/config/filter/network/sni_cluster/v2;sni_clusterv2\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.sni_cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.sni_cluster.v2.sni_cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.config.filter.network.sni_cluster.v2B\017SniClusterProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/config/filter/network/sni_cluster/v2;sni_clusterv2\362\230\376\217\0051\022/envoy.extensions.filters.network.sni_cluster.v3\272\200\310\321\006\002\020\001'
  _globals['_SNICLUSTER']._serialized_start=171
  _globals['_SNICLUSTER']._serialized_end=183
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/trace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.trace.v2 import datadog_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_datadog__pb2
from envoy.config.trace.v2 import dynamic_ot_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_dynamic__ot__pb2
from envoy.config.trace.v2 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2
from envoy.config.trace.v2 import lightstep_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_lightstep__pb2
from envoy.config.trace.v2 import service_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_service__pb2
from envoy.config.trace.v2 import zipkin_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_zipkin__pb2

from envoy.config.trace.v2.datadog_pb2 import *
from envoy.config.trace.v2.dynamic_ot_pb2 import *
from envoy.config.trace.v2.http_tracer_pb2 import *
from envoy.config.trace.v2.lightstep_pb2 import *
from envoy.config.trace.v2.service_pb2 import *
from envoy.config.trace.v2.zipkin_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/config/trace/v2/trace.proto\x12\x15\x65nvoy.config.trace.v2\x1a#envoy/config/trace/v2/datadog.proto\x1a&envoy/config/trace/v2/dynamic_ot.proto\x1a\'envoy/config/trace/v2/http_tracer.proto\x1a%envoy/config/trace/v2/lightstep.proto\x1a#envoy/config/trace/v2/service.proto\x1a\"envoy/config/trace/v2/zipkin.protoBy\n#io.envoyproxy.envoy.config.trace.v2B\nTraceProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2P\x00P\x01P\x02P\x03P\x04P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v2.trace_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v2B\nTraceProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_authz/v3/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.mutation_rules.v3 import mutation_rules_pb2 as envoy_dot_config_dot_common_dot_mutation__rules_dot_v3_dot_mutation__rules__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from envoy.type.matcher.v3 import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_metadata__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/ext_authz/v3/ext_authz.proto\x12*envoy.extensions.filters.http.ext_authz.v3\x1a:envoy/config/common/mutation_rules/v3/mutation_rules.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a#envoy/config/core/v3/http_uri.proto\x1a$envoy/type/matcher/v3/metadata.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9a\x0c\n\x08\x45xtAuthz\x12\x39\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceH\x00\x12O\n\x0chttp_service\x18\x03 \x01(\x0b\x32\x37.envoy.extensions.filters.http.ext_authz.v3.HttpServiceH\x00\x12I\n\x15transport_api_version\x18\x0c \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12%\n\x1d\x66\x61ilure_mode_allow_header_add\x18\x13 \x01(\x08\x12U\n\x11with_request_body\x18\x05 \x01(\x0b\x32:.envoy.extensions.filters.http.ext_authz.v3.BufferSettings\x12\x19\n\x11\x63lear_route_cache\x18\x06 \x01(\x08\x12\x32\n\x0fstatus_on_error\x18\x07 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12\x1a\n\x12validate_mutations\x18\x18 \x01(\x08\x12#\n\x1bmetadata_context_namespaces\x18\x08 \x03(\t\x12)\n!typed_metadata_context_namespaces\x18\x10 \x03(\t\x12)\n!route_metadata_context_namespaces\x18\x15 \x03(\t\x12/\n\'route_typed_metadata_context_namespaces\x18\x16 \x03(\t\x12\x46\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12G\n\x17\x66ilter_enabled_metadata\x18\x0e \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcher\x12\x41\n\x0f\x64\x65ny_at_disable\x18\x0b \x01(\x0b\x32(.envoy.config.core.v3.RuntimeFeatureFlag\x12 \n\x18include_peer_certificate\x18\n \x01(\x08\x12\x13\n\x0bstat_prefix\x18\r \x01(\t\x12%\n\x1d\x62ootstrap_metadata_labels_key\x18\x0f \x01(\t\x12\x41\n\x0f\x61llowed_headers\x18\x11 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12\x44\n\x12\x64isallowed_headers\x18\x19 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12\x1b\n\x13include_tls_session\x18\x12 \x01(\x08\x12\x41\n\x1d\x63harge_cluster_response_stats\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x12\x65ncode_raw_headers\x18\x17 \x01(\x08\x12\x61\n\x1d\x64\x65\x63oder_header_mutation_rules\x18\x1a \x01(\x0b\x32:.envoy.config.common.mutation_rules.v3.HeaderMutationRules\x12\x45\n!enable_dynamic_metadata_ingestion\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0f\x66ilter_metadata\x18\x1c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1f\n\x17\x65mit_filter_state_stats\x18\x1d \x01(\x08:5\x9a\xc5\x88\x1e\x30\n.envoy.config.filter.http.ext_authz.v3.ExtAuthzB\n\n\x08servicesJ\x04\x08\x04\x10\x05R\tuse_alpha\"\xa7\x01\n\x0e\x42ufferSettings\x12\"\n\x11max_request_bytes\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x1d\n\x15\x61llow_partial_message\x18\x02 \x01(\x08\x12\x15\n\rpack_as_bytes\x18\x03 \x01(\x08:;\x9a\xc5\x88\x1e\x36\n4envoy.config.filter.http.ext_authz.v2.BufferSettings\"\xeb\x02\n\x0bHttpService\x12\x31\n\nserver_uri\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUri\x12\x13\n\x0bpath_prefix\x18\x02 \x01(\t\x12_\n\x15\x61uthorization_request\x18\x07 \x01(\x0b\x32@.envoy.extensions.filters.http.ext_authz.v3.AuthorizationRequest\x12\x61\n\x16\x61uthorization_response\x18\x08 \x01(\x0b\x32\x41.envoy.extensions.filters.http.ext_authz.v3.AuthorizationResponse:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.http.ext_authz.v2.HttpServiceJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\xe4\x01\n\x14\x41uthorizationRequest\x12N\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12\x39\n\x0eheaders_to_add\x18\x02 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.ext_authz.v2.AuthorizationRequest\"\xed\x03\n\x15\x41uthorizationResponse\x12J\n\x18\x61llowed_upstream_headers\x18\x01 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12T\n\"allowed_upstream_headers_to_append\x18\x03 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12H\n\x16\x61llowed_client_headers\x18\x02 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12S\n!allowed_client_headers_on_success\x18\x04 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher\x12O\n\x1d\x64ynamic_metadata_from_headers\x18\x05 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcher:B\x9a\xc5\x88\x1e=\n;envoy.config.filter.http.ext_authz.v2.AuthorizationResponse\"\xde\x01\n\x10\x45xtAuthzPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12]\n\x0e\x63heck_settings\x18\x02 \x01(\x0b\x32\x39.envoy.extensions.filters.http.ext_authz.v3.CheckSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xfa\x02\n\rCheckSettings\x12t\n\x12\x63ontext_extensions\x18\x01 \x03(\x0b\x32P.envoy.extensions.filters.http.ext_authz.v3.CheckSettings.ContextExtensionsEntryB\x06\xb8\xb7\x8b\xa4\x02\x01\x12&\n\x1e\x64isable_request_body_buffering\x18\x02 \x01(\x08\x12U\n\x11with_request_body\x18\x03 \x01(\x0b\x32:.envoy.extensions.filters.http.ext_authz.v3.BufferSettings\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.http.ext_authz.v2.CheckSettingsB\xb2\x01\n8io.envoyproxy.envoy.extensions.filters.http.ext_authz.v3B\rExtAuthzProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_authz/v3;ext_authzv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ext_authz.v3.ext_authz_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.ext_authz.v3B\rExtAuthzProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ext_authz/v3;ext_authzv3\272\200\310\321\006\002\020\002'
  _EXTAUTHZ.fields_by_name['transport_api_version']._options = None
  _EXTAUTHZ.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _EXTAUTHZ._options = None
  _EXTAUTHZ._serialized_options = b'\232\305\210\0360\n.envoy.config.filter.http.ext_authz.v3.ExtAuthz'
  _BUFFERSETTINGS.fields_by_name['max_request_bytes']._options = None
  _BUFFERSETTINGS.fields_by_name['max_request_bytes']._serialized_options = b'\372B\004*\002 \000'
  _BUFFERSETTINGS._options = None
  _BUFFERSETTINGS._serialized_options = b'\232\305\210\0366\n4envoy.config.filter.http.ext_authz.v2.BufferSettings'
  _HTTPSERVICE._options = None
  _HTTPSERVICE._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.http.ext_authz.v2.HttpService'
  _AUTHORIZATIONREQUEST.fields_by_name['allowed_headers']._options = None
  _AUTHORIZATIONREQUEST.fields_by_name['allowed_headers']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _AUTHORIZATIONREQUEST._options = None
  _AUTHORIZATIONREQUEST._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.ext_authz.v2.AuthorizationRequest'
  _AUTHORIZATIONRESPONSE._options = None
  _AUTHORIZATIONRESPONSE._serialized_options = b'\232\305\210\036=\n;envoy.config.filter.http.ext_authz.v2.AuthorizationResponse'
  _EXTAUTHZPERROUTE.oneofs_by_name['override']._options = None
  _EXTAUTHZPERROUTE.oneofs_by_name['override']._serialized_options = b'\370B\001'
  _EXTAUTHZPERROUTE.fields_by_name['disabled']._options = None
  _EXTAUTHZPERROUTE.fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _EXTAUTHZPERROUTE.fields_by_name['check_settings']._options = None
  _EXTAUTHZPERROUTE.fields_by_name['check_settings']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTAUTHZPERROUTE._options = None
  _EXTAUTHZPERROUTE._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute'
  _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._options = None
  _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._serialized_options = b'8\001'
  _CHECKSETTINGS.fields_by_name['context_extensions']._options = None
  _CHECKSETTINGS.fields_by_name['context_extensions']._serialized_options = b'\270\267\213\244\002\001'
  _CHECKSETTINGS._options = None
  _CHECKSETTINGS._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.http.ext_authz.v2.CheckSettings'
  _globals['_EXTAUTHZ']._serialized_start=651
  _globals['_EXTAUTHZ']._serialized_end=2213
  _globals['_BUFFERSETTINGS']._serialized_start=2216
  _globals['_BUFFERSETTINGS']._serialized_end=2383
  _globals['_HTTPSERVICE']._serialized_start=2386
  _globals['_HTTPSERVICE']._serialized_end=2749
  _globals['_AUTHORIZATIONREQUEST']._serialized_start=2752
  _globals['_AUTHORIZATIONREQUEST']._serialized_end=2980
  _globals['_AUTHORIZATIONRESPONSE']._serialized_start=2983
  _globals['_AUTHORIZATIONRESPONSE']._serialized_end=3476
  _globals['_EXTAUTHZPERROUTE']._serialized_start=3479
  _globals['_EXTAUTHZPERROUTE']._serialized_end=3701
  _globals['_CHECKSETTINGS']._serialized_start=3704
  _globals['_CHECKSETTINGS']._serialized_end=4082
  _globals['_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY']._serialized_start=3966
  _globals['_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY']._serialized_end=4022
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.tap.v3 import tap_pb2 as envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2


class TapSinkServiceStub(object):
    """[#protodoc-title: Tap sink service]

    [#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call
    StreamTaps to deliver captured taps to the server
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamTaps = channel.stream_unary(
                '/envoy.service.tap.v3.TapSinkService/StreamTaps',
                request_serializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsResponse.FromString,
                )


class TapSinkServiceServicer(object):
    """[#protodoc-title: Tap sink service]

    [#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call
    StreamTaps to deliver captured taps to the server
    """

    def StreamTaps(self, request_iterator, context):
        """Envoy will connect and send StreamTapsRequest messages forever. It does not expect any
        response to be sent as nothing would be done in the case of failure. The server should
        disconnect if it expects Envoy to reconnect.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TapSinkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamTaps': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamTaps,
                    request_deserializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsRequest.FromString,
                    response_serializer=envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.tap.v3.TapSinkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TapSinkService(object):
    """[#protodoc-title: Tap sink service]

    [#not-implemented-hide:] A tap service to receive incoming taps. Envoy will call
    StreamTaps to deliver captured taps to the server
    """

    @staticmethod
    def StreamTaps(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/envoy.service.tap.v3.TapSinkService/StreamTaps',
            envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsRequest.SerializeToString,
            envoy_dot_service_dot_tap_dot_v3_dot_tap__pb2.StreamTapsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/proto_message_extraction/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/proto_message_extraction/v3/config.proto\x12\x39\x65nvoy.extensions.filters.http.proto_message_extraction.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\xe0\x04\n\x1cProtoMessageExtractionConfig\x12\x37\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x12)\n\x1fproto_descriptor_typed_metadata\x18\x02 \x01(\tH\x00\x12q\n\x04mode\x18\x03 \x01(\x0e\x32\x63.envoy.extensions.filters.http.proto_message_extraction.v3.ProtoMessageExtractionConfig.ExtractMode\x12\x8d\x01\n\x14\x65xtraction_by_method\x18\x04 \x03(\x0b\x32o.envoy.extensions.filters.http.proto_message_extraction.v3.ProtoMessageExtractionConfig.ExtractionByMethodEntry\x1a\x86\x01\n\x17\x45xtractionByMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12Z\n\x05value\x18\x02 \x01(\x0b\x32K.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction:\x02\x38\x01\">\n\x0b\x45xtractMode\x12\x1b\n\x17\x45xtractMode_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46IRST_AND_LAST\x10\x01\x42\x10\n\x0e\x64\x65scriptor_set\"\xce\x05\n\x10MethodExtraction\x12\x8e\x01\n\x1brequest_extraction_by_field\x18\x02 \x03(\x0b\x32i.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.RequestExtractionByFieldEntry\x12\x90\x01\n\x1cresponse_extraction_by_field\x18\x03 \x03(\x0b\x32j.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.ResponseExtractionByFieldEntry\x1a\x9d\x01\n\x1dRequestExtractionByFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12k\n\x05value\x18\x02 \x01(\x0e\x32\\.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.ExtractDirective:\x02\x38\x01\x1a\x9e\x01\n\x1eResponseExtractionByFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12k\n\x05value\x18\x02 \x01(\x0e\x32\\.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.ExtractDirective:\x02\x38\x01\"U\n\x10\x45xtractDirective\x12 \n\x1c\x45xtractDirective_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XTRACT\x10\x01\x12\x12\n\x0e\x45XTRACT_REDACT\x10\x02\x42\xe5\x01\nGio.envoyproxy.envoy.extensions.filters.http.proto_message_extraction.v3B\x0b\x43onfigProtoP\x01Z{github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/proto_message_extraction/v3;proto_message_extractionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.proto_message_extraction.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nGio.envoyproxy.envoy.extensions.filters.http.proto_message_extraction.v3B\013ConfigProtoP\001Z{github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/proto_message_extraction/v3;proto_message_extractionv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY._options = None
  _PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY._serialized_options = b'8\001'
  _METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY._options = None
  _METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY._serialized_options = b'8\001'
  _METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY._options = None
  _METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY._serialized_options = b'8\001'
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG']._serialized_start=231
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG']._serialized_end=839
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY']._serialized_start=623
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY']._serialized_end=757
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTMODE']._serialized_start=759
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTMODE']._serialized_end=821
  _globals['_METHODEXTRACTION']._serialized_start=842
  _globals['_METHODEXTRACTION']._serialized_end=1560
  _globals['_METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY']._serialized_start=1155
  _globals['_METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY']._serialized_end=1312
  _globals['_METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY']._serialized_start=1315
  _globals['_METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY']._serialized_end=1473
  _globals['_METHODEXTRACTION_EXTRACTDIRECTIVE']._serialized_start=1475
  _globals['_METHODEXTRACTION_EXTRACTDIRECTIVE']._serialized_end=1560
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto\x12*envoy.config.filter.network.redis_proxy.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xef\x0b\n\nRedisProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x19\n\x07\x63luster\x18\x02 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x63\n\x08settings\x18\x03 \x01(\x0b\x32G.envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11latency_in_micros\x18\x04 \x01(\x08\x12Z\n\rprefix_routes\x18\x05 \x01(\x0b\x32\x43.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes\x12G\n\x18\x64ownstream_auth_password\x18\x06 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x1a\x92\x04\n\x10\x43onnPoolSettings\x12\x37\n\nop_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x08\x01\x12\x1a\n\x12\x65nable_hashtagging\x18\x02 \x01(\x08\x12\x1a\n\x12\x65nable_redirection\x18\x03 \x01(\x08\x12$\n\x1cmax_buffer_size_before_flush\x18\x04 \x01(\r\x12\x37\n\x14\x62uffer_flush_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n max_upstream_unknown_connections\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14\x65nable_command_stats\x18\x08 \x01(\x08\x12q\n\x0bread_policy\x18\x07 \x01(\x0e\x32R.envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.ReadPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"U\n\nReadPolicy\x12\n\n\x06MASTER\x10\x00\x12\x11\n\rPREFER_MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\x12\x12\n\x0ePREFER_REPLICA\x10\x03\x12\x07\n\x03\x41NY\x10\x04\x1a\xed\x04\n\x0cPrefixRoutes\x12Y\n\x06routes\x18\x01 \x03(\x0b\x32I.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route\x12\x18\n\x10\x63\x61se_insensitive\x18\x02 \x01(\x08\x12#\n\x11\x63\x61tch_all_cluster\x18\x03 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x62\n\x0f\x63\x61tch_all_route\x18\x04 \x01(\x0b\x32I.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route\x1a\xde\x02\n\x05Route\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x15\n\rremove_prefix\x18\x02 \x01(\x08\x12\x18\n\x07\x63luster\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12|\n\x15request_mirror_policy\x18\x04 \x03(\x0b\x32].envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy\x1a\x95\x01\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x45\n\x10runtime_fraction\x18\x02 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12\x1d\n\x15\x65xclude_read_commands\x18\x03 \x01(\x08\"T\n\x14RedisProtocolOptions\x12<\n\rauth_password\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x42\xed\x01\n8io.envoyproxy.envoy.config.filter.network.redis_proxy.v2B\x0fRedisProxyProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/config/filter/network/redis_proxy/v2;redis_proxyv2\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.redis_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.config.filter.network.redis_proxy.v2B\017RedisProxyProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/config/filter/network/redis_proxy/v2;redis_proxyv2\362\230\376\217\0051\022/envoy.extensions.filters.network.redis_proxy.v3\272\200\310\321\006\002\020\001'
  _REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout']._options = None
  _REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout']._serialized_options = b'\372B\005\252\001\002\010\001'
  _REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy']._options = None
  _REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
  _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['cluster']._options = None
  _REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_cluster']._options = None
  _REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_cluster']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _REDISPROXY.fields_by_name['stat_prefix']._options = None
  _REDISPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _REDISPROXY.fields_by_name['cluster']._options = None
  _REDISPROXY.fields_by_name['cluster']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _REDISPROXY.fields_by_name['settings']._options = None
  _REDISPROXY.fields_by_name['settings']._serialized_options = b'\372B\005\212\001\002\020\001'
  _REDISPROXY.fields_by_name['downstream_auth_password']._options = None
  _REDISPROXY.fields_by_name['downstream_auth_password']._serialized_options = b'\270\267\213\244\002\001'
  _REDISPROTOCOLOPTIONS.fields_by_name['auth_password']._options = None
  _REDISPROTOCOLOPTIONS.fields_by_name['auth_password']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_REDISPROXY']._serialized_start=362
  _globals['_REDISPROXY']._serialized_end=1881
  _globals['_REDISPROXY_CONNPOOLSETTINGS']._serialized_start=727
  _globals['_REDISPROXY_CONNPOOLSETTINGS']._serialized_end=1257
  _globals['_REDISPROXY_CONNPOOLSETTINGS_READPOLICY']._serialized_start=1172
  _globals['_REDISPROXY_CONNPOOLSETTINGS_READPOLICY']._serialized_end=1257
  _globals['_REDISPROXY_PREFIXROUTES']._serialized_start=1260
  _globals['_REDISPROXY_PREFIXROUTES']._serialized_end=1881
  _globals['_REDISPROXY_PREFIXROUTES_ROUTE']._serialized_start=1531
  _globals['_REDISPROXY_PREFIXROUTES_ROUTE']._serialized_end=1881
  _globals['_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY']._serialized_start=1732
  _globals['_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY']._serialized_end=1881
  _globals['_REDISPROTOCOLOPTIONS']._serialized_start=1883
  _globals['_REDISPROTOCOLOPTIONS']._serialized_end=1967
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/connect_grpc_bridge/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/extensions/filters/http/connect_grpc_bridge/v3/config.proto\x12\x34\x65nvoy.extensions.filters.http.connect_grpc_bridge.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\x0e\n\x0c\x46ilterConfigB\xd6\x01\nBio.envoyproxy.envoy.extensions.filters.http.connect_grpc_bridge.v3B\x0b\x43onfigProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/connect_grpc_bridge/v3;connect_grpc_bridgev3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.connect_grpc_bridge.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.filters.http.connect_grpc_bridge.v3B\013ConfigProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/connect_grpc_bridge/v3;connect_grpc_bridgev3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_FILTERCONFIG']._serialized_start=187
  _globals['_FILTERCONFIG']._serialized_end=201
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.auth.v2 import external_auth_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2


class AuthorizationStub(object):
    """[#protodoc-title: Authorization Service ]

    The authorization service request messages used by external authorization :ref:`network filter
    <config_network_filters_ext_authz>` and :ref:`HTTP filter <config_http_filters_ext_authz>`.

    A generic interface for performing authorization check on incoming
    requests to a networked service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Check = channel.unary_unary(
                '/envoy.service.auth.v2.Authorization/Check',
                request_serializer=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.CheckRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.CheckResponse.FromString,
                )


class AuthorizationServicer(object):
    """[#protodoc-title: Authorization Service ]

    The authorization service request messages used by external authorization :ref:`network filter
    <config_network_filters_ext_authz>` and :ref:`HTTP filter <config_http_filters_ext_authz>`.

    A generic interface for performing authorization check on incoming
    requests to a networked service.
    """

    def Check(self, request, context):
        """Performs authorization check based on the attributes associated with the
        incoming request, and returns status `OK` or not `OK`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthorizationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Check': grpc.unary_unary_rpc_method_handler(
                    servicer.Check,
                    request_deserializer=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.CheckRequest.FromString,
                    response_serializer=envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.CheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.auth.v2.Authorization', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Authorization(object):
    """[#protodoc-title: Authorization Service ]

    The authorization service request messages used by external authorization :ref:`network filter
    <config_network_filters_ext_authz>` and :ref:`HTTP filter <config_http_filters_ext_authz>`.

    A generic interface for performing authorization check on incoming
    requests to a networked service.
    """

    @staticmethod
    def Check(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/envoy.service.auth.v2.Authorization/Check',
            envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.CheckRequest.SerializeToString,
            envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2.CheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/core/v3/tlv_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/data/core/v3/tlv_metadata.proto\x12\x12\x65nvoy.data.core.v3\x1a\x1dudpa/annotations/status.proto\"\x91\x01\n\x0cTlvsMetadata\x12K\n\x0etyped_metadata\x18\x01 \x03(\x0b\x32\x33.envoy.data.core.v3.TlvsMetadata.TypedMetadataEntry\x1a\x34\n\x12TypedMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x42\x80\x01\n io.envoyproxy.envoy.data.core.v3B\x10TlvMetadataProtoP\x01Z@github.com/envoyproxy/go-control-plane/envoy/data/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.core.v3.tlv_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.envoyproxy.envoy.data.core.v3B\020TlvMetadataProtoP\001Z@github.com/envoyproxy/go-control-plane/envoy/data/core/v3;corev3\272\200\310\321\006\002\020\002'
  _TLVSMETADATA_TYPEDMETADATAENTRY._options = None
  _TLVSMETADATA_TYPEDMETADATAENTRY._serialized_options = b'8\001'
  _globals['_TLVSMETADATA']._serialized_start=93
  _globals['_TLVSMETADATA']._serialized_end=238
  _globals['_TLVSMETADATA_TYPEDMETADATAENTRY']._serialized_start=186
  _globals['_TLVSMETADATA_TYPEDMETADATAENTRY']._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/month.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google/type/month.proto\x12\x0bgoogle.type*\xb0\x01\n\x05Month\x12\x15\n\x11MONTH_UNSPECIFIED\x10\x00\x12\x0b\n\x07JANUARY\x10\x01\x12\x0c\n\x08\x46\x45\x42RUARY\x10\x02\x12\t\n\x05MARCH\x10\x03\x12\t\n\x05\x41PRIL\x10\x04\x12\x07\n\x03MAY\x10\x05\x12\x08\n\x04JUNE\x10\x06\x12\x08\n\x04JULY\x10\x07\x12\n\n\x06\x41UGUST\x10\x08\x12\r\n\tSEPTEMBER\x10\t\x12\x0b\n\x07OCTOBER\x10\n\x12\x0c\n\x08NOVEMBER\x10\x0b\x12\x0c\n\x08\x44\x45\x43\x45MBER\x10\x0c\x42]\n\x0f\x63om.google.typeB\nMonthProtoP\x01Z6google.golang.org/genproto/googleapis/type/month;month\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.month_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\nMonthProtoP\001Z6google.golang.org/genproto/googleapis/type/month;month\242\002\003GTP'
  _globals['_MONTH']._serialized_start=41
  _globals['_MONTH']._serialized_end=217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/field_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgoogle/api/field_info.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"\xc1\x01\n\tFieldInfo\x12,\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x1c.google.api.FieldInfo.Format\x12\x33\n\x10referenced_types\x18\x02 \x03(\x0b\x32\x19.google.api.TypeReference\"Q\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\t\n\x05UUID4\x10\x01\x12\x08\n\x04IPV4\x10\x02\x12\x08\n\x04IPV6\x10\x03\x12\x10\n\x0cIPV4_OR_IPV6\x10\x04\"\"\n\rTypeReference\x12\x11\n\ttype_name\x18\x01 \x01(\t:L\n\nfield_info\x12\x1d.google.protobuf.FieldOptions\x18\xcc\xf1\xf9\x8a\x01 \x01(\x0b\x32\x15.google.api.FieldInfoBl\n\x0e\x63om.google.apiB\x0e\x46ieldInfoProtoP\x01ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.field_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\016FieldInfoProtoP\001ZAgoogle.golang.org/genproto/googleapis/api/annotations;annotations\242\002\004GAPI'
  _globals['_FIELDINFO']._serialized_start=78
  _globals['_FIELDINFO']._serialized_end=271
  _globals['_FIELDINFO_FORMAT']._serialized_start=190
  _globals['_FIELDINFO_FORMAT']._serialized_end=271
  _globals['_TYPEREFERENCE']._serialized_start=273
  _globals['_TYPEREFERENCE']._serialized_end=307
# @@protoc_insertion_point(module_scope)
